affine — rasterio/affine development documentation

# affine

Affine transformation matrices.

The Affine package is derived from Casey Duncan’s Planar package. See the copyright statement below.

Module Attributes

`identity` | The identity transform

Functions

`cos_sin_deg`(deg) | Return the cosine and sin for the given angle in degrees.
`dumpsw`(obj) | Return string for a world file.
`loadsw`(s) | Return Affine from the contents of a world file string.

Classes

`Affine`(a, b, c, d, e, f[, g, h, i]) | Two dimensional affine transform for 2D linear mapping.

Exceptions

`AffineError` |
`TransformNotInvertibleError` | The transform could not be inverted.
`UndefinedRotationError` | The rotation angle could not be computed for this transform.